# coding: utf-8

# flake8: noqa
# coding: utf-8

"""
    Production

    ##### API Overview - Accounts list and balance - Transaction overview (also for saving accounts) - Payments import - Statement list and download - FX rates  ##### Authentication Before making a call to Premium API, you need to register your app at our _Developer portal_. This is where you get the **ClientID** that your application must send in the request as &#x60;X-IBM-Client-Id&#x60;. This is the key that grants your app access to the API.  However, this may not be enough. Your application needs to use mTLS to call most operations here. Thus, you not only need _https_ but also a client certificate issued by us. The exception is two operations for FX rates that are accessible also without a client certificate.  Each bank client/user can issue several certificates. Each certificate can permit different sets of operations (http methods) on different bank accounts. All this must be configured in Internet Banking first by each bank client/user (bank clients need to look under _Settings_ and do not forget to download the certificate at the last step). The certificate is downloaded in **PKCS#12** format as **\\*.p12** file and protected by a password chosen by the bank client/user. Yes, your app needs the password as well to get use of the **\\*p12** file for establishing mTLS connection to the bank.  Client certificates issued in Internet Banking for bank clients/users have limited validity (e.g. **5 years**). However, **each year** certificates are automatically blocked and bank client/user must unblock them in Internet Banking. It is possible to do it in advance and prolong the time before the certificate is blocked. Your app should be prepared for these scenarios and it should communicate such cases to your user in advance to provide seamless service and high user-experience of your app.  ##### Rate Limiting The number of requests in each API operation is limited to 10 per client per sliding second and 5000 per client per sliding day. The exception is the &#39;Download Statement&#39; operation with the limits lowered to 5 per client per sliding second and 1500 per client per sliding day. This is because it transports potentially sizeable binary files. The consumer must be able to handle HTTP status 429 in case of exceeding these limits.  Response headers &#x60;X-RateLimit-Limit-Second&#x60; and &#x60;X-RateLimit-Limit-Day&#x60; show the actual limits configured for the specific operation. Response headers &#x60;X-RateLimit-Remaining-Second&#x60; and &#x60;X-RateLimit-Remaining-Day&#x60; are returned to help prevent the limits from being exceeded.  ##### Notes Be aware, that in certain error situations, API can return specific error structures along with 5xx status code, which is not explicitely defined below.  ##### Quick Start Client Feel free to download a &lt;a href&#x3D;\&quot;assets/PremiumApiClient.java\&quot; download&gt;simple Java client&lt;/a&gt; that gives you quick access to our API. 

    The version of the OpenAPI document: 1.1.20240910
    Generated by OpenAPI Generator: https://openapi-generator.tech

    Do not edit the class manually.
"""

# import models into model package
from rbczpremiumapi.Model.currency_list_simple import CurrencyListSimple
from rbczpremiumapi.Model.download_statement_request import DownloadStatementRequest
from rbczpremiumapi.Model.exchange_rate import ExchangeRate
from rbczpremiumapi.Model.exchange_rate_list import ExchangeRateList
from rbczpremiumapi.Model.get_accounts200_response import GetAccounts200Response
from rbczpremiumapi.Model.get_accounts200_response_accounts_inner import GetAccounts200ResponseAccountsInner
from rbczpremiumapi.Model.get_balance200_response import GetBalance200Response
from rbczpremiumapi.Model.get_balance200_response_currency_folders_inner import GetBalance200ResponseCurrencyFoldersInner
from rbczpremiumapi.Model.get_balance200_response_currency_folders_inner_balances_inner import GetBalance200ResponseCurrencyFoldersInnerBalancesInner
from rbczpremiumapi.Model.get_balance401_response import GetBalance401Response
from rbczpremiumapi.Model.get_balance403_response import GetBalance403Response
from rbczpremiumapi.Model.get_balance404_response import GetBalance404Response
from rbczpremiumapi.Model.get_balance429_response import GetBalance429Response
from rbczpremiumapi.Model.get_batch_detail200_response import GetBatchDetail200Response
from rbczpremiumapi.Model.get_batch_detail200_response_batch_items_inner import GetBatchDetail200ResponseBatchItemsInner
from rbczpremiumapi.Model.get_batch_detail200_response_batch_items_inner_account_info import GetBatchDetail200ResponseBatchItemsInnerAccountInfo
from rbczpremiumapi.Model.get_batch_detail400_response import GetBatchDetail400Response
from rbczpremiumapi.Model.get_statements200_response import GetStatements200Response
from rbczpremiumapi.Model.get_statements200_response_statements_inner import GetStatements200ResponseStatementsInner
from rbczpremiumapi.Model.get_statements400_response import GetStatements400Response
from rbczpremiumapi.Model.get_statements_request import GetStatementsRequest
from rbczpremiumapi.Model.get_transaction_list200_response import GetTransactionList200Response
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner import GetTransactionList200ResponseTransactionsInner
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_amount import GetTransactionList200ResponseTransactionsInnerAmount
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_bank_transaction_code import GetTransactionList200ResponseTransactionsInnerBankTransactionCode
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details import GetTransactionList200ResponseTransactionsInnerEntryDetails
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetails
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_instructed_amount import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsInstructedAmount
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_references import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsReferences
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedParties
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties_counter_party import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedPartiesCounterParty
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties_counter_party_account import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedPartiesCounterPartyAccount
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties_counter_party_organisation_identification import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedPartiesCounterPartyOrganisationIdentification
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties_counter_party_organisation_identification_postal_address import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedPartiesCounterPartyOrganisationIdentificationPostalAddress
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties_counter_party_postal_address import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedPartiesCounterPartyPostalAddress
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties_intermediary_institution import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedPartiesIntermediaryInstitution
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties_intermediary_institution_postal_address import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedPartiesIntermediaryInstitutionPostalAddress
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_related_parties_ultimate_counter_party import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRelatedPartiesUltimateCounterParty
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_remittance_information import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRemittanceInformation
from rbczpremiumapi.Model.get_transaction_list200_response_transactions_inner_entry_details_transaction_details_remittance_information_creditor_reference_information import GetTransactionList200ResponseTransactionsInnerEntryDetailsTransactionDetailsRemittanceInformationCreditorReferenceInformation
from rbczpremiumapi.Model.get_transaction_list400_response import GetTransactionList400Response
from rbczpremiumapi.Model.import_payments200_response import ImportPayments200Response
from rbczpremiumapi.Model.import_payments400_response import ImportPayments400Response
from rbczpremiumapi.Model.import_payments413_response import ImportPayments413Response
from rbczpremiumapi.Model.import_payments415_response import ImportPayments415Response
